From 79a113d1baf04cd22ce4aed280763c555a872281 Mon Sep 17 00:00:00 2001
From: Hauke Petersen <hauke.petersen@fu-berlin.de>
Date: Fri, 24 Feb 2017 08:57:11 +0100
Subject: [PATCH] sys/drivers: renamed uuid module to luid

---
 drivers/Makefile.dep             | 14 +++----
 drivers/at86rf2xx/at86rf2xx.c    |  4 +-
 drivers/cc110x/cc110x.c          |  4 +-
 drivers/cc2420/cc2420.c          |  4 +-
 drivers/enc28j60/enc28j60.c      |  4 +-
 drivers/kw2xrf/kw2xrf.c          |  4 +-
 drivers/mrf24j40/mrf24j40.c      |  4 +-
 drivers/w5100/w5100.c            |  4 +-
 sys/include/{uuid.h => luid.h}   | 68 ++++++++++++++++----------------
 sys/{uuid => luid}/Makefile      |  0
 sys/{uuid/uuid.c => luid/luid.c} | 18 ++++-----
 11 files changed, 64 insertions(+), 64 deletions(-)
 rename sys/include/{uuid.h => luid.h} (55%)
 rename sys/{uuid => luid}/Makefile (100%)
 rename sys/{uuid/uuid.c => luid/luid.c} (73%)

diff --git a/drivers/Makefile.dep b/drivers/Makefile.dep
index d269da604f..531a6b7c6a 100644
--- a/drivers/Makefile.dep
+++ b/drivers/Makefile.dep
@@ -8,7 +8,7 @@ endif
 ifneq (,$(filter at86rf2%,$(USEMODULE)))
   USEMODULE += at86rf2xx
   USEMODULE += xtimer
-  USEMODULE += uuid
+  USEMODULE += luid
   USEMODULE += netif
   USEMODULE += ieee802154
   USEMODULE += netdev2_ieee802154
@@ -21,7 +21,7 @@ endif
 
 ifneq (,$(filter mrf24j40,$(USEMODULE)))
   USEMODULE += xtimer
-  USEMODULE += uuid
+  USEMODULE += luid
   USEMODULE += netif
   USEMODULE += ieee802154
   USEMODULE += netdev2_ieee802154
@@ -49,7 +49,7 @@ endif
 
 ifneq (,$(filter cc110x,$(USEMODULE)))
   USEMODULE += ieee802154
-  USEMODULE += uuid
+  USEMODULE += luid
   USEMODULE += xtimer
   ifneq (,$(filter gnrc_netdev_default,$(USEMODULE)))
     USEMODULE += gnrc_cc110x
@@ -61,7 +61,7 @@ endif
 
 ifneq (,$(filter cc2420,$(USEMODULE)))
   USEMODULE += xtimer
-  USEMODULE += uuid
+  USEMODULE += luid
   USEMODULE += netif
   USEMODULE += ieee802154
   USEMODULE += netdev2_ieee802154
@@ -82,7 +82,7 @@ endif
 ifneq (,$(filter enc28j60,$(USEMODULE)))
   USEMODULE += netdev2_eth
   USEMODULE += xtimer
-  USEMODULE += uuid
+  USEMODULE += luid
 endif
 
 ifneq (,$(filter encx24j600,$(USEMODULE)))
@@ -114,7 +114,7 @@ ifneq (,$(filter jc42,$(USEMODULE)))
 endif
 
 ifneq (,$(filter kw2xrf,$(USEMODULE)))
-    USEMODULE += uuid
+    USEMODULE += luid
     USEMODULE += netif
     USEMODULE += ieee802154
     USEMODULE += netdev2_ieee802154
@@ -186,7 +186,7 @@ endif
 
 ifneq (,$(filter w5100,$(USEMODULE)))
   USEMODULE += netdev2_eth
-  USEMODULE += uuid
+  USEMODULE += luid
 endif
 
 ifneq (,$(filter xbee,$(USEMODULE)))
diff --git a/drivers/at86rf2xx/at86rf2xx.c b/drivers/at86rf2xx/at86rf2xx.c
index ebeab759d8..b77193548b 100644
--- a/drivers/at86rf2xx/at86rf2xx.c
+++ b/drivers/at86rf2xx/at86rf2xx.c
@@ -24,7 +24,7 @@
  */
 
 
-#include "uuid.h"
+#include "luid.h"
 #include "byteorder.h"
 #include "net/ieee802154.h"
 #include "net/gnrc.h"
@@ -62,7 +62,7 @@ void at86rf2xx_reset(at86rf2xx_t *dev)
     dev->netdev.flags = 0;
 
     /* get an 8-byte unique ID to use as hardware address */
-    uuid_get(addr_long.uint8, IEEE802154_LONG_ADDRESS_LEN);
+    luid_get(addr_long.uint8, IEEE802154_LONG_ADDRESS_LEN);
     /* make sure we mark the address as non-multicast and not globally unique */
     addr_long.uint8[0] &= ~(0x01);
     addr_long.uint8[0] |=  (0x02);
diff --git a/drivers/cc110x/cc110x.c b/drivers/cc110x/cc110x.c
index 0286ed5b04..5107db8542 100644
--- a/drivers/cc110x/cc110x.c
+++ b/drivers/cc110x/cc110x.c
@@ -20,7 +20,7 @@
  * @}
  */
 
-#include "uuid.h"
+#include "luid.h"
 #include "board.h"
 #include "periph/gpio.h"
 #include "periph/spi.h"
@@ -82,7 +82,7 @@ int cc110x_setup(cc110x_t *dev, const cc110x_params_t *params)
 
     /* set default node id */
     uint8_t addr;
-    uuid_get(&addr, 1);
+    luid_get(&addr, 1);
     cc110x_set_address(dev, addr);
 
     LOG_INFO("cc110x: initialized with address=%u and channel=%i\n",
diff --git a/drivers/cc2420/cc2420.c b/drivers/cc2420/cc2420.c
index 24d8ef2a8b..4dd4a195f0 100644
--- a/drivers/cc2420/cc2420.c
+++ b/drivers/cc2420/cc2420.c
@@ -20,7 +20,7 @@
  * @}
  */
 
-#include "uuid.h"
+#include "luid.h"
 #include "byteorder.h"
 #include "net/ieee802154.h"
 #include "net/gnrc.h"
@@ -54,7 +54,7 @@ int cc2420_init(cc2420_t *dev)
     dev->netdev.flags = 0;
 
     /* set default address, channel, PAN ID, and TX power */
-    uuid_get(addr, sizeof(addr));
+    luid_get(addr, sizeof(addr));
     /* make sure we mark the address as non-multicast and not globally unique */
     addr[0] &= ~(0x01);
     addr[0] |= 0x02;
diff --git a/drivers/enc28j60/enc28j60.c b/drivers/enc28j60/enc28j60.c
index ee8d0ca8a0..f43c4f34b7 100644
--- a/drivers/enc28j60/enc28j60.c
+++ b/drivers/enc28j60/enc28j60.c
@@ -21,7 +21,7 @@
 #include <errno.h>
 #include <string.h>
 
-#include "uuid.h"
+#include "luid.h"
 #include "mutex.h"
 #include "xtimer.h"
 #include "assert.h"
@@ -373,7 +373,7 @@ static int nd_init(netdev2_t *netdev)
     cmd_wcr(dev, REG_B2_MAIPGL, 2, MAIPGL_FD);
     /* set default MAC address */
     uint8_t macbuf[ETHERNET_ADDR_LEN];
-    uuid_get(macbuf, ETHERNET_ADDR_LEN);
+    luid_get(macbuf, ETHERNET_ADDR_LEN);
     macbuf[0] |= 0x02;      /* locally administered address */
     macbuf[0] &= ~0x01;     /* unicast address */
     mac_set(dev, macbuf);
diff --git a/drivers/kw2xrf/kw2xrf.c b/drivers/kw2xrf/kw2xrf.c
index 5cb8d7cb7e..b9bbfd20e3 100644
--- a/drivers/kw2xrf/kw2xrf.c
+++ b/drivers/kw2xrf/kw2xrf.c
@@ -28,7 +28,7 @@
 #include "periph/cpuid.h"
 #include "net/gnrc.h"
 #include "net/ieee802154.h"
-#include "uuid.h"
+#include "luid.h"
 
 #include "kw2xrf.h"
 #include "kw2xrf_spi.h"
@@ -45,7 +45,7 @@ static void kw2xrf_set_address(kw2xrf_t *dev)
     DEBUG("[kw2xrf] set MAC addresses\n");
     eui64_t addr_long;
     /* get an 8-byte unique ID to use as hardware address */
-    uuid_get(addr_long.uint8, IEEE802154_LONG_ADDRESS_LEN);
+    luid_get(addr_long.uint8, IEEE802154_LONG_ADDRESS_LEN);
     /* make sure we mark the address as non-multicast and not globally unique */
     addr_long.uint8[0] &= ~(0x01);
     addr_long.uint8[0] |=  (0x02);
diff --git a/drivers/mrf24j40/mrf24j40.c b/drivers/mrf24j40/mrf24j40.c
index 8a26a02ab9..302036c4aa 100644
--- a/drivers/mrf24j40/mrf24j40.c
+++ b/drivers/mrf24j40/mrf24j40.c
@@ -20,7 +20,7 @@
  * @}
  */
 
-#include "uuid.h"
+#include "luid.h"
 #include "byteorder.h"
 #include "net/gnrc.h"
 #include "mrf24j40_registers.h"
@@ -51,7 +51,7 @@ void mrf24j40_reset(mrf24j40_t *dev)
     dev->netdev.flags = 0;
 
     /* get an 8-byte unique ID to use as hardware address */
-    uuid_get(addr_long.uint8, IEEE802154_LONG_ADDRESS_LEN);
+    luid_get(addr_long.uint8, IEEE802154_LONG_ADDRESS_LEN);
     addr_long.uint8[0] &= ~(0x01);
     addr_long.uint8[0] |=  (0x02);
     /* set short and long address */
diff --git a/drivers/w5100/w5100.c b/drivers/w5100/w5100.c
index 443d61883f..00dc89a35a 100644
--- a/drivers/w5100/w5100.c
+++ b/drivers/w5100/w5100.c
@@ -22,7 +22,7 @@
 #include <string.h>
 
 #include "log.h"
-#include "uuid.h"
+#include "luid.h"
 #include "assert.h"
 
 #include "net/ethernet.h"
@@ -148,7 +148,7 @@ static int init(netdev2_t *netdev)
     while (rreg(dev, REG_MODE) & MODE_RESET) {};
 
     /* initialize the device, start with writing the MAC address */
-    uuid_get(hwaddr, ETHERNET_ADDR_LEN);
+    luid_get(hwaddr, ETHERNET_ADDR_LEN);
     hwaddr[0] &= ~0x03;         /* no group address and not globally unique */
     wchunk(dev, REG_SHAR0, hwaddr, ETHERNET_ADDR_LEN);
 
diff --git a/sys/include/uuid.h b/sys/include/luid.h
similarity index 55%
rename from sys/include/uuid.h
rename to sys/include/luid.h
index aa6ef59029..974013f4d1 100644
--- a/sys/include/uuid.h
+++ b/sys/include/luid.h
@@ -7,13 +7,13 @@
  */
 
 /**
  * @defgroup    sys_uuid (Locally) Unique ID Generator
  * @ingroup     sys
- * @brief       Generate system wide unique IDs
+ * @brief       Generate system wide (locally) unique IDs
  *
  * This module generates system wide, variable length unique IDs based on on the
  * cpuid module. If the cpuid module is not present, the module falls back to a
- * pre-defined, constant seed for creating unique ids.
+ * pre-defined, constant seed for creating unique IDs.
  *
  * The main purpose of this module is to have a unified way for e.g. creating
  * hardware addresses and similar.
@@ -24,24 +24,24 @@
  * base ID is created by simple 'memsetting' the base ID with the defined
  * backup seed value.
  *
- * Once the base ID is generated, a UUID is generated by (i) XORing a counter
+ * Once the base ID is generated, a LUID is generated by (i) XORing a counter
  * value with the LSB of the base ID, or (ii) by XORing the least significant
  * byes with a value given by the user.
  *
  * Example: Calling `uuid_base(&buf, 8)` will always yield an identical  value,
  * independent how often the function is called. But calling
  * `uuid_base(&buf, 2)` afterwards will results in a different value, if the
  * cpuid module is present, and in the same (but shorter) value if not.
  *
  * Example: Calling `uuid_get(&buf, 8)` four times in a row, will yield four
  * different IDs, differing in their LSB.
  *
  * Example: Calling `uuid_custom(&buf, 8, 123)` will always yield the same
  * value, but calling `uuid_custom(&buf, 8, 124)` will differ.
  *
- * @note        This module generates unique IDs without any guarantees on their
- *              structure. These UUIDs are not compatible nor conform to the
- *              UUIDs as defined in RFC4122.
+ * @note        This module generates locally unique IDs without any guarantees
+ *              on their structure. These LUIDs are not compatible nor conform
+ *              to UUIDs as defined in RFC4122.
  *
  * @{
  * @file
@@ -50,8 +50,8 @@
  * @author      Hauke Petersen <hauke.petersen@fu-berlin.de>
  */
 
-#ifndef UUID_H_
-#define UUID_H_
+#ifndef LUID_H_
+#define LUID_H_
 
 #include <stddef.h>
 
@@ -60,27 +60,27 @@ extern "C" {
 #endif
 
 /**
- * @brief   Value used as based for the UUIDs in case the cpuid module is not
+ * @brief   Value used as based for the LUIDs in case the cpuid module is not
  *          present
  */
-#ifndef UUID_BACKUP_SEED
-#define UUID_BACKUP_SEED        0x23
+#ifndef LUID_BACKUP_SEED
+#define LUID_BACKUP_SEED        0x23
 #endif
 
 /**
  * @brief   Get a unique ID
  *
- * The resulting ID is built from the base ID generated with uuid_base(), which
+ * The resulting ID is built from the base ID generated with luid_base(), which
  * isXORed with an 8-bit incrementing counter value into the most significant
  * byte.
  *
  * @note    The resulting UUID will repeat after 255 calls.
  *
  * @param[out] buf      memory location to copy the UUID into. MUST be able to
  *                      hold at least @p len bytes
  * @param[in]  len      length of the UUID in bytes
  */
-void uuid_get(void *buf, size_t len);
+void luid_get(void *buf, size_t len);
 
 /**
  * @brief   Get a custom unique ID based on a user given generator value
@@ -89,31 +89,31 @@ void uuid_get(void *buf, size_t len);
  * ID's most significant bytes.
  *
  * @note    Calling this function with identical values for @p gen and @p len
- *          will always result in identical UUIDs.
+ *          will always result in identical LUIDs.
  *
  * @param[out] buf      memory location to copy the UUID into. MUST be able to
  *                      hold at least @p len bytes
  * @param[in]  len      length of the UUID in bytes
  * @param[in]  gen      custom UUID generator value
  */
-void uuid_custom(void *buf, size_t len, int gen);
+void luid_custom(void *buf, size_t len, int gen);
 
 /**
  * @brief   Get a UUID base value
  *
  * The uuid module creates the value dependent on the given @p len value using
  * the cpuid module if present or a static seed value (@ref UUID_BACKUP_SEED) if
  * not.
  *
  * @param[out] buf      memory location to copy the UUID into. MUST be able to
  *                      hold at least @p len bytes
  * @param[in]  len      length of the UUID in bytes
  */
-void uuid_base(void *buf, size_t len);
+void luid_base(void *buf, size_t len);
 
 #ifdef __cplusplus
 }
 #endif
 
-#endif /* UUID_H_ */
+#endif /* LUID_H_ */
 /** @} */
@@ -7,13 +7,13 @@
 
 /**
- * @defgroup    sys_uuid (Locally) Unique ID Generator
+ * @defgroup    sys_luid Locally Unique ID Generator
  * @ingroup     sys
@@ -24,24 +24,24 @@
  * byes with a value given by the user.
  *
- * Example: Calling `uuid_base(&buf, 8)` will always yield an identical  value,
+ * Example: Calling `luid_base(&buf, 8)` will always yield an identical  value,
  * independent how often the function is called. But calling
@@ -24,24 +24,24 @@
  * independent how often the function is called. But calling
- * `uuid_base(&buf, 2)` afterwards will results in a different value, if the
+ * `luid_base(&buf, 2)` afterwards will results in a different value, if the
  * cpuid module is present, and in the same (but shorter) value if not.
  *
@@ -24,24 +24,24 @@
  * cpuid module is present, and in the same (but shorter) value if not.
  *
- * Example: Calling `uuid_get(&buf, 8)` four times in a row, will yield four
+ * Example: Calling `luid_get(&buf, 8)` four times in a row, will yield four
  * different IDs, differing in their LSB.
  *
@@ -24,24 +24,24 @@
  * different IDs, differing in their LSB.
  *
- * Example: Calling `uuid_custom(&buf, 8, 123)` will always yield the same
- * value, but calling `uuid_custom(&buf, 8, 124)` will differ.
+ * Example: Calling `luid_custom(&buf, 8, 123)` will always yield the same
+ * value, but calling `luid_custom(&buf, 8, 124)` will differ.
  *
@@ -60,27 +60,27 @@ extern "C" {
  * byte.
  *
- * @note    The resulting UUID will repeat after 255 calls.
+ * @note    The resulting LUID will repeat after 255 calls.
  *
@@ -60,27 +60,27 @@ extern "C" {
  *
- * @param[out] buf      memory location to copy the UUID into. MUST be able to
+ * @param[out] buf      memory location to copy the LUID into. MUST be able to
  *                      hold at least @p len bytes
@@ -60,27 +60,27 @@ extern "C" {
  *                      hold at least @p len bytes
- * @param[in]  len      length of the UUID in bytes
+ * @param[in]  len      length of the LUID in bytes
  */
@@ -89,31 +89,31 @@ void uuid_get(void *buf, size_t len);
  *
- * @param[out] buf      memory location to copy the UUID into. MUST be able to
+ * @param[out] buf      memory location to copy the LUID into. MUST be able to
  *                      hold at least @p len bytes
@@ -89,31 +89,31 @@ void uuid_get(void *buf, size_t len);
  *                      hold at least @p len bytes
- * @param[in]  len      length of the UUID in bytes
- * @param[in]  gen      custom UUID generator value
+ * @param[in]  len      length of the LUID in bytes
+ * @param[in]  gen      custom LUID generator value
  */
@@ -89,31 +89,31 @@ void uuid_get(void *buf, size_t len);
 
 /**
- * @brief   Get a UUID base value
+ * @brief   Get a LUID base value
  *
@@ -89,31 +89,31 @@ void uuid_get(void *buf, size_t len);
  *
- * The uuid module creates the value dependent on the given @p len value using
- * the cpuid module if present or a static seed value (@ref UUID_BACKUP_SEED) if
+ * The luid module creates the value dependent on the given @p len value using
+ * the cpuid module if present or a static seed value (@ref LUID_BACKUP_SEED) if
  * not.
  *
@@ -89,31 +89,31 @@ void uuid_get(void *buf, size_t len);
  * not.
  *
- * @param[out] buf      memory location to copy the UUID into. MUST be able to
+ * @param[out] buf      memory location to copy the LUID into. MUST be able to
  *                      hold at least @p len bytes
@@ -89,31 +89,31 @@ void uuid_get(void *buf, size_t len);
  *                      hold at least @p len bytes
- * @param[in]  len      length of the UUID in bytes
+ * @param[in]  len      length of the LUID in bytes
  */
diff --git a/sys/uuid/Makefile b/sys/luid/Makefile
similarity index 100%
rename from sys/uuid/Makefile
rename to sys/luid/Makefile
diff --git a/sys/uuid/uuid.c b/sys/luid/luid.c
similarity index 73%
rename from sys/uuid/uuid.c
rename to sys/luid/luid.c
index b71eddc68c..1b7a876ce1 100644
--- a/sys/uuid/uuid.c
+++ b/sys/luid/luid.c
@@ -7,11 +7,11 @@
  */
 
 /**
- * @ingroup     sys_uuid
+ * @ingroup     sys_luid
  * @{
  *
  * @file
  * @brief       UUID module implementation
  *
  * @author      Hauke Petersen <hauke.petersen@fu-berlin.de>
  *
@@ -24,31 +24,31 @@
 #include "assert.h"
 #include "periph/cpuid.h"
 
-#include "uuid.h"
+#include "luid.h"
 
 static uint8_t lastused = 1;
 
-void uuid_get(void *buf, size_t len)
+void luid_get(void *buf, size_t len)
 {
-    uuid_base(buf, len);
+    luid_base(buf, len);
 
     ((uint8_t *)buf)[0] ^= lastused++;
 }
 
-void uuid_custom(void *buf, size_t len, int gen)
+void luid_custom(void *buf, size_t len, int gen)
 {
-    uuid_base(buf, len);
+    luid_base(buf, len);
 
     for (size_t i = 0; i < sizeof(gen); i++) {
         ((uint8_t *)buf)[i % len] ^= ((gen >> (i * 8)) & 0xff);
     }
 }
 
-void uuid_base(void *buf, size_t len)
+void luid_base(void *buf, size_t len)
 {
     assert(buf && (len > 0));
 
-    memset(buf, UUID_BACKUP_SEED, len);
+    memset(buf, LUID_BACKUP_SEED, len);
 
 #if CPUID_LEN
     uint8_t *out = (uint8_t *)buf;
@@ -7,11 +7,11 @@
  *
  * @file
- * @brief       UUID module implementation
+ * @brief       LUID module implementation
  *
  * @author      Hauke Petersen <hauke.petersen@fu-berlin.de>
-- 
GitLab